@@ -34,9 +34,8 @@ import os
 import sys
 
 
-
 # Read environment variable if it exists
-SIDEKIT_CONFIG={"libsvm":True,
+SIDEKIT_CONFIG={"libsvm":False,
                 "mpi":False,
                 "cuda":True
                 }
@@ -111,11 +110,17 @@ from .iv_scoring import cosine_scoring
 from .iv_scoring import mahalanobis_scoring
 from .iv_scoring import two_covariance_scoring
 from .iv_scoring import PLDA_scoring
+from .iv_scoring import fast_PLDA_scoring
 
 from .gmm_scoring import gmm_scoring
 
 from .jfa_scoring import jfa_scoring
 
+from .score_normalization import znorm
+from .score_normalization import tnorm
+from .score_normalization import ztnorm
+from .score_normalization import snorm
+
 from .sidekit_io import write_norm_hdf5
 from .sidekit_io import write_matrix_hdf5
 
@@ -157,17 +162,10 @@ if SIDEKIT_CONFIG["cuda"]:
 
 
 if CUDA:
-    from .nnet import FForwardNetwork
-    from .nnet import kaldi_to_hdf5
-    from .nnet import XvectorMultiDataset
-    from .nnet import XvectorDataset
-    from .nnet import StatDataset
     from .nnet import Xtractor
     from .nnet import xtrain
     from .nnet import extract_embeddings
-    from .nnet import extract_sliding_embedding
     from .nnet import ResBlock
-    from .nnet import ResNet18
     from .nnet import SincNet
 
 else:
@@ -189,5 +187,5 @@ __maintainer__ = "Anthony Larcher"
 __email__ = "anthony.larcher@univ-lemans.fr"
 __status__ = "Production"
 __docformat__ = 'reStructuredText'
-__version__="1.3.8.5.2"
+__version__="1.4.1"
 
