@@ -235,8 +235,8 @@ class Key:
         with h5py.File(input_file_fame, "r") as f:
 
             key = Key()
-            key.modelset = f.get("modelset")[()]
-            key.segset = f.get("segset")[()]
+            key.modelset = f["modelset"][()]
+            key.segset = f["segset"][()]
 
             # if running python 3, need a conversion to unicode
             if sys.version_info[0] == 3:
