@@ -163,12 +163,18 @@ class Scores:
         :return: a vector of target scores.
             :return: a vector of non-target scores.
         """
-        new_score = self.align_with_ndx(key)
-        tarndx = key.tar & new_score.scoremask
-        nonndx = key.non & new_score.scoremask
-        tar = new_score.scoremat[tarndx]
-        non = new_score.scoremat[nonndx]
-        return tar, non
+        if (key.modelset == self.modelset).all() \
+            and (key.segset == self.segset).all() \
+                and self.scoremask.shape[0] == key.tar.shape[0] \
+                    and self.scoremask.shape[1] == key.tar.shape[1]:
+            return self.scoremat[key.tar & self.scoremask], self.scoremat[key.non & self.scoremask]
+        else:
+            new_score = self.align_with_ndx(key)
+            tarndx = key.tar & new_score.scoremask
+            nonndx = key.non & new_score.scoremask
+            tar = new_score.scoremat[tarndx]
+            non = new_score.scoremat[nonndx]
+            return tar, non
 
     def align_with_ndx(self, ndx):
         """The ordering in the output Scores object corresponds to ndx, so
