@@ -386,6 +386,7 @@ class FactorAnalyser:
 
         # Estimate  TV iteratively
         for it in range(nb_iter):
+            print(f"Start it: {it}")
             # Create accumulators for the list of models to process
             _A = numpy.zeros((nb_distrib, tv_rank, tv_rank), dtype=STAT_TYPE)
             _C = numpy.zeros((tv_rank, feature_size * nb_distrib), dtype=STAT_TYPE)
@@ -606,7 +607,7 @@ class FactorAnalyser:
 
         # Estimate  TV iteratively
         for it in range(nb_iter):
-
+            print(f"Iteration {it}")
             # Create serialized accumulators for the list of models to process
             with warnings.catch_warnings():
                 warnings.simplefilter('ignore', RuntimeWarning)
