@@ -310,8 +310,7 @@ class FeaturesExtractor(object):
         dir_name = os.path.dirname(feature_filename)  # get the path
         if not os.path.exists(dir_name) and not (dir_name == ''):
             os.makedirs(dir_name) 
-
-        h5f = h5py.File(feature_filename, 'a', backing_store=backing_store, driver='core')
+        h5f = h5py.File(feature_filename, 'w', backing_store=backing_store, driver='core')
         if "cep" not in self.save_param:
             cep = None
             cep_mean = None
@@ -584,6 +583,7 @@ class FeaturesExtractor(object):
             else:
                 tmp_dict[show][_id] = numpy.concatenate((tmp_dict[show][_id], numpy.arange(start, stop-1)), axis=0)
 
+
         output_show = list()
         output_id = list()
         output_start = list()
