@@ -27,13 +27,15 @@ Copyright 2014-2021 Anthony Larcher and Sylvain Meignier
 """
 import copy
 import logging
+import sys
+
 import numpy
 import scipy
-from sidekit.bosaris import Ndx
-from sidekit.bosaris import Scores
+import torch
+
+from sidekit.bosaris import Ndx, Scores
 from sidekit.statserver import StatServer
 
-import sys
 if sys.version_info.major > 2:
     from functools import reduce
 
@@ -58,7 +60,7 @@ def _check_missing_model(enroll, test, ndx):
     return clean_ndx
 
 
-def cosine_scoring(enroll, test, ndx, wccn=None, check_missing=True):
+def cosine_scoring(enroll, test, ndx, wccn=None, check_missing=True, device=None):
     """Compute the cosine similarities between to sets of vectors. The list of 
     trials to perform is given in an Ndx object.
     
@@ -96,10 +98,15 @@ def cosine_scoring(enroll, test, ndx, wccn=None, check_missing=True):
     enroll_copy.norm_stat1()
     if enroll_copy != test_copy:
         test_copy.norm_stat1()
-    s = numpy.dot(enroll_copy.stat1, test_copy.stat1.transpose())
+    s_size_in_bytes = enroll_copy.stat1.shape[0] * test_copy.stat1.shape[0] * 4
+    if device == None:
+        device = torch.device("cuda:0" if torch.cuda.is_available() and s_size_in_bytes < 3e9 else "cpu")
+    else:
+        device = device if torch.cuda.is_available() and s_size_in_bytes < 3e9 else torch.device("cpu")
 
     score = Scores()
-    score.scoremat = s
+    score.scoremat = torch.einsum('ij,kj', torch.FloatTensor(enroll_copy.stat1).to(device),
+                                  torch.FloatTensor(test_copy.stat1).to(device)).cpu().numpy()
     score.modelset = clean_ndx.modelset
     score.segset = clean_ndx.segset
     score.scoremask = clean_ndx.trialmask
